@@ -1,15 +1,16 @@
 package App::lcpan::Cmd::author_deps;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-10'; # DATE
+our $DATE = '2020-06-11'; # DATE
 our $DIST = 'App-lcpan'; # DIST
-our $VERSION = '1.059'; # VERSION
+our $VERSION = '1.060'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 
 require App::lcpan;
+use Hash::Subset qw(hash_subset);
 
 our %SPEC;
 
@@ -63,18 +64,24 @@ sub handle_cmd {
 
     my $author = $args{author};
 
-    my $res = App::lcpan::modules(%args, author=>$author);
+    my $res = App::lcpan::dists(
+        hash_subset(\%args, \%App::lcpan::common_args, \%App::lcpan::author_args),
+    );
     return $res if $res->[0] != 200;
-    my $mods = $res->[2];
+    my $dists = $res->[2];
 
     my %deps_args = %args;
-    $deps_args{modules} = $mods;
+    $deps_args{dists} = $dists;
+    delete $deps_args{author};
     delete $deps_args{authors};
     delete $deps_args{authors_arent};
-    $deps_args{authors} = $args{module_authors};
-    $deps_args{authors_arent} = $args{module_authors_arent};
-    $deps_args{phase} = $args{phase};
-    $deps_args{rel} = $args{rel};
+    $deps_args{authors} = delete $args{module_authors};
+    $deps_args{authors_arent} = delete $args{module_authors_arent};
+    $deps_args{phase} = delete $args{phase};
+    $deps_args{rel} = delete $args{rel};
+    $deps_args{added_since} = delete $args{added_since};
+    $deps_args{updated_since} = delete $args{updated_since};
+    $deps_args{added_or_updated_since} = delete $args{added_or_updated_since};
     $res = App::lcpan::deps(%deps_args);
     return $res if $res->[0] != 200;
 
@@ -96,7 +103,7 @@ App::lcpan::Cmd::author_deps - List dependencies for all of the dists of an auth
 
 =head1 VERSION
 
-This document describes version 1.059 of App::lcpan::Cmd::author_deps (from Perl distribution App-lcpan), released on 2020-06-10.
+This document describes version 1.060 of App::lcpan::Cmd::author_deps (from Perl distribution App-lcpan), released on 2020-06-11.
 
 =head1 FUNCTIONS
 
