@@ -1,13 +1,14 @@
 package App::lcpan::Cmd::author_rdeps;
 
-our $DATE = '2020-06-10'; # DATE
-our $VERSION = '1.059'; # VERSION
+our $DATE = '2020-06-11'; # DATE
+our $VERSION = '1.060'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 
 require App::lcpan;
+use Hash::Subset 'hash_subset';
 
 our %SPEC;
 
@@ -40,18 +41,24 @@ sub handle_cmd {
 
     my $author = $args{author};
 
-    my $res = App::lcpan::modules(%args, author=>$author);
+    my $res = App::lcpan::modules(
+        hash_subset(\%args, \%App::lcpan::common_args, \%App::lcpan::author_args),
+    );
     return $res if $res->[0] != 200;
 
     my $mods = $res->[2];
     my %rdeps_args = %args;
     $rdeps_args{modules} = $mods;
+    delete $rdeps_args{author};
     delete $rdeps_args{authors};
     delete $rdeps_args{authors_arent};
-    $rdeps_args{authors} = $args{user_authors};
-    $rdeps_args{authors_arent} = $args{user_authors_arent};
-    $rdeps_args{phase} = $args{phase};
-    $rdeps_args{rel} = $args{rel};
+    $rdeps_args{authors} = delete $args{user_authors};
+    $rdeps_args{authors_arent} = delete $args{user_authors_arent};
+    $rdeps_args{phase} = delete $args{phase};
+    $rdeps_args{rel} = delete $args{rel};
+    $rdeps_args{added_since} = delete $args{added_since};
+    $rdeps_args{updated_since} = delete $args{updated_since};
+    $rdeps_args{added_or_updated_since} = delete $args{added_or_updated_since};
     $res = App::lcpan::rdeps(%rdeps_args);
     return $res if $res->[0] != 200;
 
@@ -73,7 +80,7 @@ App::lcpan::Cmd::author_rdeps - Find distributions that use one of author's modu
 
 =head1 VERSION
 
-This document describes version 1.059 of App::lcpan::Cmd::author_rdeps (from Perl distribution App-lcpan), released on 2020-06-10.
+This document describes version 1.060 of App::lcpan::Cmd::author_rdeps (from Perl distribution App-lcpan), released on 2020-06-11.
 
 =head1 FUNCTIONS
 
